import io
import os
import sys
import m3u8
import subprocess
import imagehash
from PIL import Image
from datetime import datetime
from requests import get

operating_system = sys.platform

filepath = os.path.dirname(os.path.realpath(__file__))

base_stream_url = 'https://5ea8aa5cf299b.streamlock.net/'
lower_base_url = 'HA/house_360p/'
upper_base_url = 'LC/legco_360p/'

class Stream(object):
    lower_img_hash = imagehash.average_hash(Image.open(filepath + '/tas_img/ha_adjourned.png'))
    upper_img_hash = imagehash.average_hash(Image.open(filepath + '/tas_img/lc_adjourned.png'))

    @property
    def lower_stream_url(self):
        return(base_stream_url + lower_base_url + 'playlist.m3u8')

    @property
    def upper_stream_url(self):
        return(base_stream_url + upper_base_url + 'playlist.m3u8')

    @property
    def stream_urls(self):
        return({'lower': self.lower_stream_url, 'upper': self.upper_stream_url})


    @property
    def lower_is_live(self):
        if(self.lower_img_hash - self.__get_vid_hash(self.lower_stream_url, lower_base_url) < 5):
            return(False)
        else:
            return(True)
        
    @property
    def upper_is_live(self):
        if(self.upper_img_hash - self.__get_vid_hash(self.upper_stream_url, upper_base_url) < 5):
            return(False)
        else:
            return(True)

    def __get_vid_hash(self, input_url, base_url):
        try:
            if(operating_system != 'win32'):
                root_dir = '/tmp/'
            else:
                root_dir = 'C:/temp/'
            playlist_data = m3u8.loads(get(input_url).text)
            seg_uri = m3u8.loads(get(base_stream_url + base_url + playlist_data.data['playlists'][0]['uri']).text).data['segments'][-1]['uri']
            seg_ts = get(base_stream_url + base_url + seg_uri)
            current_time = str(datetime.now()).replace(':', '-').replace('.', '-').replace(' ', '_')
            seg_output_file = root_dir + current_time + '_seg.ts'
            open(seg_output_file, 'wb').write(seg_ts.content)
            img_out = root_dir + current_time + '_seg_out.png'
            
            command = ['-ss', '00:00:00', '-i', seg_output_file, '-frames:v', '1', img_out]
            if(operating_system != 'win32'):
                subprocess.run(['ffmpeg'] + command, capture_output=True)
            else:
                subprocess.run(['ffmpeg.exe'] + command, capture_output=True)
            
            return(imagehash.average_hash((Image.open(img_out))))
        except:
            raise Exception('Invalid input URL: ' + input_url)


import json
import m3u8
import http.cookiejar
from requests import get
from bs4 import BeautifulSoup

refer_url = 'https://api-v3.switchmedia.asia/'
api_url = [refer_url + '277/assets/get-data?asset=11725', '&detail=verbose&format=json']
stream_base_url = 'https://dps-live-hls.global.ssl.fastly.net/hls/'
num_range = range(68, 71)
page_soup = BeautifulSoup(get('https://www.aph.gov.au/Watch_Read_Listen').text, 'lxml')

class Stream(object):
    def __init__(self):
        self.__get_stream_urls()
    
    def __get_stream_urls(self):
        self.sittings = []
        self.sitting_div = page_soup.find('div', {'id': 'content'}).find_all('p', {'class': 'watch-live text-center'})
        for row in self.sitting_div:
            self.sittings.append(row.text.strip())
        for asset_id in num_range:
            json_data = json.loads(get(api_url[0] + str(asset_id) + api_url[1]).text)[0]
            prefix_id = json_data['image'].replace('https://downloads.switchmedia.asia/filestore/getimage.php?siteID=', '')[:3]
            # prefix_id = '277'
            stream_id = json_data['title'][-3:]
            house_id = json_data['synopsis'].replace('Live Stream: ', '')[:3]
            url_suffix = prefix_id + '_' + house_id + stream_id + '_18000_01.m3u8'
            url = stream_base_url + url_suffix
            if(house_id == 'HOR'):
                self.lower_stream_url = url
            elif(house_id == 'COM'):
                self.committee_stream_url = url
            elif(house_id == 'SEN'):
                self.upper_stream_url = url
            else:
                raise Exception('An error occurred, got house_id ' + str(house_id))

    @property
    def lower_is_live(self):
        if(self.sittings[0] == 'Not sitting'):
           return(False)
        else:
           return(True)
        
    @property
    def upper_is_live(self):
        if(self.sittings[2] == 'Not sitting'):
           return(False)
        else:
           return(True)
    
    @property
    def committee_is_live(self):
        if(self.sittings[1] == 'Not sitting'):
           return(False)
        else:
           return(True)
    
    @property
    def stream_urls(self):
        return {'lower': self.lower_stream_url, 'upper': self.upper_stream_url, 'committee': self.committee_stream_url}


import m3u8
from requests import get

api_url = 'http://video.dpa.act.gov.au/live/amlst:aod-recording/playlist.m3u8?DVR'

class Stream(object):
    def __init__(self):
        self.__read_playlist(api_url)
    
    def __read_playlist(self, input_url):
        playlist_data = m3u8.loads(get(input_url).text)
        self.lower_stream_url = 'http://video.dpa.act.gov.au/live/amlst:aod-recording/' + playlist_data.data['playlists'][2]['uri']
        self.stream_urls = {'lower': self.lower_stream_url}

    @property
    def lower_is_live(self):
        if(get(self.lower_stream_url).status_code == 404):
            return(False)
        else:
            return(True)


import m3u8
import json
from requests import get

data_json = 'https://player-api.new.livestream.com/accounts/13067949/events/'
info_suffix = '/stream_info'

class Stream(object):
    def __init__(self):
        try:
            self.__get_data(data_json)
        except:
            raise Exception('Unable to get JSON data: ' + data_json)

    def __get_data(self, input_json):
        self.parsed_data = json.loads(get(input_json).text)['data']
    
    @property
    def lower_stream_url(self):
        return(self.__get_stream_url('Legislative Assembly'))

    @property
    def upper_stream_url(self):
        return(self.__get_stream_url('Legislative Council'))
    
    @property
    def committe_stream_url(self):
        return(self.__get_stream_url('Macquarie Room'))
    
    @property
    def jubilee_stream_url(self):
        return(self.__get_stream_url('Jubilee Room'))

    @property
    def jubilee_is_live(self):
        try:
            get(self.jubilee_stream_url)
            return(True)
        except:
            return(False)

    @property
    def committee_is_live(self):
        try:
            get(self.committe_stream_url)
            return(True)
        except:
            return(False)
        
    @property
    def lower_is_live(self):
        try:
            get(self.lower_stream_url)
            return(True)
        except:
            return(False)
        
    @property
    def upper_is_live(self):
        try:
            get(self.upper_stream_url)
            return(True)
        except:
            return(False)

    @property
    def stream_urls(self):
        return({'lower': self.lower_stream_url, 'upper': self.upper_stream_url, 'committee': self.committe_stream_url, 'jubilee': self.jubilee_stream_url})

    def __get_stream_url(self, input_title):
        for stream in self.parsed_data:
            if(input_title == stream['full_name']):
                stream_id = str(stream['id'])
                stream_json_data = json.loads(get(data_json + stream_id + info_suffix).text)
                try:
                    stream_json_data['name']
                    return ''
                except:
                    res = get(stream_json_data['secure_m3u8_url'], allow_redirects=True)
                    return res.url


from requests import get

stream_url = 'http://pbs1.nt.gov.au/HLS/HDPull/playlist.m3u8'

class Stream(object):
    @property
    def lower_is_live(self):
        try:
            get(stream_url)
            return True
        except:
            return False

    @property
    def lower_stream_url(self):
        if(self.lower_is_live):
            return stream_url
        else:
            return ''

    @property
    def stream_urls(self):
        return({'lower': self.lower_stream_url})


import m3u8
import json
import urllib3
from requests import get

urllib3.disable_warnings()

lower_master = 'https://streamer1.parliament.wa.gov.au/live/smil:AssemblyLinqStream.smil/playlist.m3u8'
upper_master = 'https://streamer2.parliament.wa.gov.au/live/smil:CouncilLinqStream.smil/playlist.m3u8'

class Stream(object):
    @property
    def lower_is_live(self):
        try:
            with get(lower_master, verify=False) as res:
                if(res.status_code != 200):
                    return False
                else:
                    return True
        except:
            return False

    @property
    def upper_is_live(self):
        try:
            with get(upper_master, verify=False) as res:
                if(res.status_code != 200):
                    return False
                else:
                    return True
        except:
            return False

    @property
    def lower_stream_url(self):
        if(self.lower_is_live):
            return('https://streamer1.parliament.wa.gov.au/live/smil:AssemblyLinqStream.smil/' + self.__get_playlist(lower_master))

    @property
    def upper_stream_url(self):
        if(self.upper_is_live):
            return('https://streamer2.parliament.wa.gov.au/live/smil:CouncilLinqStream.smil/' + self.__get_playlist(upper_master))

    @property
    def stream_urls(self):
        return({'lower': self.lower_stream_url, 'upper': self.upper_stream_url})

    def __get_playlist(self, input_url):
        dat = m3u8.parse(get(input_url, verify=False).text)
        return(dat['playlists'][0]['uri'])


from setuptools import setup, find_packages
import pathlib

here = pathlib.Path(__file__).parent.resolve()

long_description = (here / 'README.md').read_text(encoding='utf-8')

setup(
    name='legistream-backend',
    version='0.9.1',
    description='Get live stream metadata from the various Australian parliaments.',
    long_description=long_description,
    long_description_content_type='text/markdown',
    url='https://github.com/OpenGovAus/legistream-backend',
    author='king-millez',
    author_email='millez.dev@gmail.com',
    classifiers=[
        'Programming Language :: Python :: 3',
        'Operating System :: OS Independent',
    ],
    packages=find_packages(),
    python_requires='>=3.6'
)


import m3u8
from requests import get

streams = ['https://pov_broadcast-i.akamaihd.net/hls/live/250374/pov-desk-la/master_900.m3u8',
           'https://pov_broadcast-i.akamaihd.net/hls/live/250376/pov-desk-lc/master_900.m3u8',
           'https://pov_broadcast-i.akamaihd.net/hls/live/250375/pov-desk-comm/master_900.m3u8']

class Stream(object):
    @property
    def lower_stream_url(self):
        return(streams[0])

    @property
    def upper_stream_url(self):
        return(streams[1])
    
    @property
    def committee_stream_url(self):
        return(streams[2])

    @property
    def stream_urls(self):
        return({'lower': self.lower_stream_url, 'upper': self.upper_stream_url, 'committee': self.committee_stream_url})

    @property
    def lower_is_live(self):
        if(get(self.lower_stream_url[:-15] + 'master_400.m3u8').status_code == 404):
            return False
        else:
            return True
        
    @property
    def upper_is_live(self):
        if(get(self.lower_stream_url[:-15] + 'master_400.m3u8').status_code == 404):
            return False
        else:
            return True
        
    @property
    def committee_is_live(self):
        if(get(self.committee_stream_url[:-15] + 'master_400.m3u8').status_code == 404):
            return False
        else:
            return True